<template>
    <div class="full-page bg">
        <div class="search-container">
            <el-form ref="form" :model="searchForm" label-width="auto">
                <el-row :gutter="20">
                    <el-col :span="5">
                        <el-form-item label="“一件事”事项名称">
                            <el-input v-model="searchForm.name" clearable placeholder="请输入事项名称"></el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="事项类型">
                            <dict-select dictCode="sjlx" :hasDefaultOption="true" clearable v-model="searchForm.eventType"
                                style="width: 100%" placeholder="请选择事项类型" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="事项类别">
                            <dict-select dictCode="yjs_sxlb" :hasDefaultOption="true" clearable v-model="searchForm.type"
                                style="width: 100%" placeholder="请选择事项类别" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="所属跑道">
							<el-input v-model="searchForm.appertainSunway" clearable placeholder="请输入所属跑道"></el-input>
                            
                            <!-- <el-select v-model="searchForm.appertainSunway" style="width: 100%" clearable
                                placeholder="请选择所属跑道">
                                <el-option v-for="item in szcq_sspd" :key="item.value" :label="item.name"
                                    :value="item.value">
                                </el-option>
                            </el-select> -->
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="loadData(searchForm)">
                            {{ this.$t('common.search') }}
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <div style="margin-bottom: 10px" ref="btnPanel">
                </div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table stripe size="mini" v-loading="tableLoading" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{
                            width: '100%',
                            height: `${tableMaxHeight}` + 'px'
                        }" @selection-change="handleSelectionChange">
                        <!-- <el-table-column type="selection" width="55" align="center"></el-table-column> -->
                        <el-table-column type="index" width="55" label="序号" align="center">
                        </el-table-column>

                        <el-table-column prop="name" show-overflow-tooltip min-width="180" align="center" label="“一件事”事项名称">
                        </el-table-column>
                        <el-table-column prop="eventType" show-overflow-tooltip  align="center" label="事项类型">
                            <template v-slot="{ row }">
                                {{ getDictName('sjlx', row.eventType) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="type" show-overflow-tooltip  align="center" label="事项类别">
                            <template v-slot="{ row }">
                                {{ getDictName('yjs_sxlb', row.type) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="appertainSystem" show-overflow-tooltip  align="center"
                            label="所属系统(体系)">
                            <template v-slot="{ row }">
                                {{ getDictName('ssxt', row.appertainSystem) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="appertainSunway" show-overflow-tooltip  align="center"
                            label="所属跑道">
                            <template v-slot="{ row }">
                                {{ getDictName('szcq_sspd', row.appertainSunway) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="libraryTime" show-overflow-tooltip min-width="150" align="center"
                            label="入库时间">
                        </el-table-column>
                        <el-table-column prop="reportCounty" show-overflow-tooltip  align="center"
                            label="提报区县">
                        </el-table-column>
                        <el-table-column show-overflow-tooltip min-width="250" align="center" label="一图两清单">
                            <template slot-scope="props">
                                <FileList v-if="props.row.townFileLists &&
                                    props.row.townFileLists.length
                                    " :fileList="props.row.townFileLists"></FileList>
                                <span style="font-size: 12px" v-else>暂无附件</span>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="searchForm"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
    </div>
</template>
    
<script>
import _ from 'lodash'
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import req from '@/request.js'
import utils from '@/utils.js'
import FileList from '@/components/uploadFile/newFileList.vue'
const portal = window.context.portal
export default {
    name: 'AdvanceApproval',
    components: {
        pagination,
        FileList
    },
    mixins: [TableMixin],
    data() {
        return {
            tableMaxHeight: 400,
            loading: false,
            tableLoading: false,
            tableData: [],
            multipleSelection: [],
            params: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0
                },
                querys: [{
                    group: 'main',
                    operation: 'EQUAL',
                    property: 'status',
                    relation: 'AND',
                    value: 2
                }]
            },
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0
            },
            searchForm: {
                page: 1,
                size: 20,
                total: 0,
                status: [5]
            }, // 顶部搜索对象
            activeCollapse1: ['1', '2'],
            fileList: [], // 文件上传
            dialog: {
                title: '审核',
                visible: false
            },
            dialogForm: {
                otherComments: []
            },
            disabled: false, // 是否禁止输入输入
            isShowBtn: false, // 是否显示底部按钮
            turnDownVisible: false,
            rules: {
                otherComments: {
                    required: true,
                    message: '请选择满足标准情况',
                    trigger: 'blur'
                },
            },
            checkList: [],
            zzmh_mzbzqk: [],
            yjs_sxlb: [], //事项类别
            szcq_sspd: [], //所属跑道
            ssxt: [], //所属系统
            treeData: [],
            sjlx: [],//事项类型
        }
    },

    created() {
        this.sjlx = utils.getDictItemsFromCache('sjlx')
        this.yjs_sxlb = utils.getDictItemsFromCache('yjs_sxlb')
        this.zzmh_mzbzqk = utils.getDictItemsFromCache('zzmh_mzbzqk')
        this.szcq_sspd = utils.getDictItemsFromCache('szcq_sspd')
        this.ssxt = utils.getDictItemsFromCache('ssxt')
        this.treeData = JSON.parse(sessionStorage.getItem('responsibilityTree'))
        this.loadData(this.searchForm)
    },
    methods: {
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        //获取数据
        loadData(params) {
            this.tableLoading = true
            req
                .post(
                    portal + '/bizEventCounty/v1/directoryLibrary?isAffirm=true',
                    params
                )
                .then(res => {
                    this.tableLoading = false
                    const data = (res && res.data) || {}
                    this.tableData = data.rows || []
                    this.searchForm.page = data.page
                    this.searchForm.size = data.pageSize
                    this.searchForm.total = data.total

                })
        },
        handleClose() {
            this.turnDownVisible = false
        },
        handleSelectionChange() { },
        handleCurrentChange(page) {
            this.searchForm.page = page
            this.loadData(this.searchForm)
        },
        handleSizeChange(pageSize) {
            this.searchForm.size = pageSize
            this.loadData(this.searchForm)
        }
    },
}
</script>
    
<style lang="scss" scoped>
.fullpage {
    height: 100%;
    width: 100%;
}

/deep/.el-pagination {
    text-align: right;
}

// /deep/.el-form-item__content {
//     width: calc(100% - 110px)
// }
/deep/.el-table__expand-column .cell {
    display: none;
}

.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.move-tree /deep/ .el-tree {
    height: 90%;
    overflow-y: auto;
    border: none;
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;

    &:nth-child(1) {
        margin-right: 5px;
    }

    &:nth-child(2) {
        margin-right: 5px;
    }

    &:nth-child(1):hover {
        background-color: #2761ff;
        color: #fff;
    }

    &:nth-child(2):hover {
        background-color: #2761ff;
        color: #fff;
    }

    // &:nth-child(2):hover {
    //   background-color: #f56c6c;
    //   color: #fff;
    //   border-color: #f56c6c;
    // }
    /deep/ i,
    span {
        font-size: 16px;
    }
}

.input_placeholder {
    /deep/input::-webkit-input-placeholder {
        color: #606266;
        font-size: 12px;
    }
}

/deep/ .el-tree-node__content {
    padding: 5px 0;
}
</style>
    